@@ -461,10 +461,6 @@
 #include "e-book-client.h"
 #include "e-book-client-cursor.h"
 
-#define E_BOOK_CLIENT_CURSOR_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_BOOK_CLIENT_CURSOR, EBookClientCursorPrivate))
-
 /* Forward declarations */
 typedef struct _SetSexpContext        SetSexpContext;
 typedef struct _StepContext           StepContext;
@@ -668,6 +664,7 @@ G_DEFINE_TYPE_WITH_CODE (
 	EBookClientCursor,
 	e_book_client_cursor,
 	G_TYPE_OBJECT,
+	G_ADD_PRIVATE (EBookClientCursor)
 	G_IMPLEMENT_INTERFACE (
 		G_TYPE_INITABLE,
 		e_book_client_cursor_initable_init))
@@ -923,14 +920,12 @@ e_book_client_cursor_class_init (EBookClientCursorClass *class)
 		G_STRUCT_OFFSET (EBookClientCursorClass, refresh),
 		NULL, NULL, NULL,
 		G_TYPE_NONE, 0);
-
-	g_type_class_add_private (class, sizeof (EBookClientCursorPrivate));
 }
 
 static void
 e_book_client_cursor_init (EBookClientCursor *cursor)
 {
-	cursor->priv = E_BOOK_CLIENT_CURSOR_GET_PRIVATE (cursor);
+	cursor->priv = e_book_client_cursor_get_instance_private (cursor);
 
 	g_mutex_init (&cursor->priv->main_context_lock);
 	g_mutex_init (&cursor->priv->notifications_lock);
