@@ -43,10 +43,6 @@ extern gint camel_application_is_exiting;
 
 typedef struct _FolderChangedData FolderChangedData;
 
-#define CAMEL_VEE_FOLDER_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_VEE_FOLDER, CamelVeeFolderPrivate))
-
 struct _CamelVeeFolderPrivate {
 	guint32 flags;		/* folder open flags */
 	gboolean destroyed;
@@ -80,7 +76,7 @@ enum {
 	PROP_AUTO_UPDATE = 0x2401
 };
 
-G_DEFINE_TYPE (CamelVeeFolder, camel_vee_folder, CAMEL_TYPE_FOLDER)
+G_DEFINE_TYPE_WITH_PRIVATE (CamelVeeFolder, camel_vee_folder, CAMEL_TYPE_FOLDER)
 
 struct _FolderChangedData {
 	CamelFolderChangeInfo *changes;
@@ -845,25 +841,6 @@ vee_folder_add_subfolder_uids_to_search_matches (CamelVeeDataCache *data_cache,
 	}
 }
 
-static const gchar *
-vee_folder_combine_expressions (CamelVeeFolder *vfolder,
-				const gchar *expression,
-				gchar **tmp)
-{
-	const gchar *my_expression;
-
-	my_expression = camel_vee_folder_get_expression (vfolder);
-
-	if (!expression || !*expression) {
-		expression = my_expression;
-	} else if (my_expression && *my_expression) {
-		*tmp = g_strconcat ("(and ", expression, " ", my_expression, ")", NULL);
-		expression = *tmp;
-	}
-
-	return expression;
-}
-
 static GPtrArray *
 vee_folder_search_by_expression (CamelFolder *folder,
                                  const gchar *expression,
@@ -874,7 +851,6 @@ vee_folder_search_by_expression (CamelFolder *folder,
 	CamelVeeDataCache *data_cache;
 	GPtrArray *matches = NULL;
 	GList *link;
-	gchar *tmp = NULL;
 
 	g_return_val_if_fail (CAMEL_IS_VEE_FOLDER (folder), NULL);
 
@@ -883,8 +859,6 @@ vee_folder_search_by_expression (CamelFolder *folder,
 
 	g_rec_mutex_lock (&vfolder->priv->subfolder_lock);
 
-	expression = vee_folder_combine_expressions (vfolder, expression, &tmp);
-
 	for (link = vfolder->priv->subfolders; link && !g_cancellable_is_cancelled (cancellable); link = g_list_next (link)) {
 		CamelFolder *subfolder = link->data;
 		GPtrArray *submatches;
@@ -903,8 +877,6 @@ vee_folder_search_by_expression (CamelFolder *folder,
 		}
 	}
 
-	g_free (tmp);
-
 	g_rec_mutex_unlock (&vfolder->priv->subfolder_lock);
 
 	if (g_cancellable_set_error_if_cancelled (cancellable, error)) {
@@ -971,7 +943,6 @@ vee_folder_search_by_uids (CamelFolder *folder,
 	GPtrArray *matches = NULL;
 	GList *link;
 	guint ii;
-	gchar *tmp = NULL;
 
 	g_return_val_if_fail (CAMEL_IS_VEE_FOLDER (folder), NULL);
 
@@ -1002,8 +973,6 @@ vee_folder_search_by_uids (CamelFolder *folder,
 
 	g_rec_mutex_lock (&vfolder->priv->subfolder_lock);
 
-	expression = vee_folder_combine_expressions (vfolder, expression, &tmp);
-
 	for (link = vfolder->priv->subfolders; link && !g_cancellable_is_cancelled (cancellable); link = g_list_next (link)) {
 		CamelFolder *subfolder = link->data;
 		GPtrArray *submatches, *subuids;
@@ -1036,8 +1005,6 @@ vee_folder_search_by_uids (CamelFolder *folder,
 		}
 	}
 
-	g_free (tmp);
-
 	g_rec_mutex_unlock (&vfolder->priv->subfolder_lock);
 
 	if (g_cancellable_set_error_if_cancelled (cancellable, error)) {
@@ -1062,7 +1029,6 @@ vee_folder_count_by_expression (CamelFolder *folder,
 {
 	CamelVeeFolder *vfolder;
 	GList *link;
-	gchar *tmp = NULL;
 	guint32 count = 0;
 
 	g_return_val_if_fail (CAMEL_IS_VEE_FOLDER (folder), 0);
@@ -1071,16 +1037,12 @@ vee_folder_count_by_expression (CamelFolder *folder,
 
 	g_rec_mutex_lock (&vfolder->priv->subfolder_lock);
 
-	expression = vee_folder_combine_expressions (vfolder, expression, &tmp);
-
 	for (link = vfolder->priv->subfolders; link && !g_cancellable_is_cancelled (cancellable); link = g_list_next (link)) {
 		CamelFolder *subfolder = link->data;
 
 		count += camel_folder_count_by_expression (subfolder, expression, cancellable, NULL);
 	}
 
-	g_free (tmp);
-
 	g_rec_mutex_unlock (&vfolder->priv->subfolder_lock);
 
 	if (g_cancellable_set_error_if_cancelled (cancellable, error))
@@ -1511,8 +1473,6 @@ camel_vee_folder_class_init (CamelVeeFolderClass *class)
 	GObjectClass *object_class;
 	CamelFolderClass *folder_class;
 
-	g_type_class_add_private (class, sizeof (CamelVeeFolderPrivate));
-
 	object_class = G_OBJECT_CLASS (class);
 	object_class->dispose = vee_folder_dispose;
 	object_class->finalize = vee_folder_finalize;
@@ -1560,7 +1520,7 @@ camel_vee_folder_init (CamelVeeFolder *vee_folder)
 {
 	CamelFolder *folder = CAMEL_FOLDER (vee_folder);
 
-	vee_folder->priv = CAMEL_VEE_FOLDER_GET_PRIVATE (vee_folder);
+	vee_folder->priv = camel_vee_folder_get_instance_private (vee_folder);
 
 	camel_folder_set_flags (folder, camel_folder_get_flags (folder) | CAMEL_FOLDER_HAS_SUMMARY_CAPABILITY);
 
